@@ -3,7 +3,7 @@ package ObjectDB::Table;
 use strict;
 use warnings;
 
-our $VERSION = '3.09';
+our $VERSION = '3.10';
 
 use constant DEFAULT_PAGE_SIZE => 10;
 
@@ -96,7 +96,7 @@ sub find {
     if (my $cb = $params->{each}) {
         while (my $row = $sth->fetchrow_arrayref) {
             my $rows = [[@$row]];
-            $rows = merge_rows $select->from_rows($rows);
+            $rows = $select->from_rows($rows);
 
             my $object =
               $self->meta->class->new(%{$rows->[0]});
@@ -111,7 +111,7 @@ sub find {
         my $rows = $sth->fetchall_arrayref;
         return unless $rows && @$rows;
 
-        $rows = merge_rows $select->from_rows($rows);
+        $rows = $select->from_rows($rows);
 
         my @objects =
           map { $_->is_in_db(1) }
